/*
 * $URL: $
 * 
 * $Revision: $
 * 
 * $Date: $
 *
 * Copyright (c) 2008, The DSpace Foundation.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * - Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * - Neither the name of the DSpace Foundation nor the names of its 
 * contributors may be used to endorse or promote products derived from 
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
package org.dspace.services.model.metadata;

import java.math.BigInteger;

/**
 * If at least one value string constraint is given, any value string must match
 * at least one of the constraints. If no value string constraint is given, any
 * value string is allowed. All Literal constraints can be used for value
 * strings as well.
 * 
 * For each value string constraint, the following may be specified.
 * 
 * XML Element Name: ValueStringConstraint
 * 
 * @author mdiggory
 */
public class ValueStringConstraint extends LiteralConstraint
{

    private BigInteger maxOccurs;

    private BigInteger minOccurs;

    /**
     * The maximum number of times this kind of value string is allowed to
     * appear in the enclosing Statement.
     * 
     * Allowed values; non-negative integer or "infinity" Default: "infinity"
     * 
     * Conditions: must be equal or greater than the Minimum occurrence
     * 
     * XML Attribute Name: maxOccurs
     * 
     * @return Max Occurance
     */
    public BigInteger getMaxOccurs()
    {
        return maxOccurs;
    }

    /**
     * The maximum number of times this kind of value string is allowed to
     * appear in the enclosing Statement.
     * 
     * Allowed values; non-negative integer or "infinity" Default: "infinity"
     * 
     * Conditions: must be equal or greater than the Minimum occurrence
     * 
     * XML Attribute Name: maxOccurs
     * 
     * @param value
     */
    public void setMaxOccurs(BigInteger value)
    {
        this.maxOccurs = value;
    }

    /**
     * The minimum number of times this kind of value string must appear in the
     * enclosing Statement.
     * 
     * Allowed values: non-negative integer
     * 
     * Default: 0
     * 
     * Conditions: must be equal or less than the Maximum occurrence
     * 
     * XML Attribute Name: minOccurs
     * 
     * @return Min Occurance
     */
    public BigInteger getMinOccurs()
    {
        return minOccurs;
    }

    /**
     * The minimum number of times this kind of value string must appear in the
     * enclosing Statement.
     * 
     * Allowed values: non-negative integer
     * 
     * Default: 0
     * 
     * Conditions: must be equal or less than the Maximum occurrence
     * 
     * XML Attribute Name: minOccurs
     * 
     * @param value
     */
    public void setMinOccurs(BigInteger value)
    {
        this.minOccurs = value;
    }

}